# arvd_ap

This project is done for fun and to learn how python modules are created. Since I'm spending some of my valuable resource called "Time" 
I've slao included some useful functions inside this.The following text will tell you what are the functions that I've initiased under this.
They are: avg(),sign(),perfect_num(),armstrong_num(),palindrome_num(),primality(),fib(),vowel_count(),consonant_count(),space_count(),
palindrome_str(),word_count(),alpha_count(),int_count() and div_it().

## Installation

To install the package, use the following command:

Or else go to PyPI.com and serch for the module named rvd_ap. So you'll find it there.

```sh
pip install arvd_ap
